@@ -1,5 +1,23 @@
-#ifndef _SIGC_ADAPTORS_EXCEPTION_CATCH_H_
-#define _SIGC_ADAPTORS_EXCEPTION_CATCH_H_
+/*
+ * Copyright 2003 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_ADAPTORS_EXCEPTION_CATCH_H
+#define SIGC_ADAPTORS_EXCEPTION_CATCH_H
 #include <sigc++/adaptors/adapts.h>
 
 namespace sigc
@@ -55,7 +73,7 @@ namespace sigc
  * @ingroup adaptors
  */
 
-template <class T_functor, class T_catcher>
+template <typename T_functor, typename T_catcher>
 struct exception_catch_functor : public adapts<T_functor>
 {
   decltype(auto) operator()()
@@ -70,12 +88,12 @@ struct exception_catch_functor : public adapts<T_functor>
     }
   }
 
-  template <class... T_arg>
-  decltype(auto) operator()(T_arg... _A_a)
+  template <typename... T_arg>
+  decltype(auto) operator()(T_arg... a)
   {
     try
     {
-      return this->functor_.template operator()<type_trait_pass_t<T_arg>...>(_A_a...);
+      return this->functor_.template operator()<type_trait_pass_t<T_arg>...>(a...);
     }
     catch (...)
     {
@@ -83,8 +101,8 @@ struct exception_catch_functor : public adapts<T_functor>
     }
   }
 
-  exception_catch_functor(const T_functor& _A_func, const T_catcher& _A_catcher)
-  : adapts<T_functor>(_A_func), catcher_(_A_catcher)
+  exception_catch_functor(const T_functor& func, const T_catcher& catcher)
+  : adapts<T_functor>(func), catcher_(catcher)
   {
   }
 
@@ -93,25 +111,25 @@ struct exception_catch_functor : public adapts<T_functor>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // template specialization of visitor<>::do_visit_each<>(action, functor):
-template <class T_functor, class T_catcher>
+template <typename T_functor, typename T_catcher>
 struct visitor<exception_catch_functor<T_functor, T_catcher>>
 {
   template <typename T_action>
-  static void do_visit_each(const T_action& _A_action,
-    const exception_catch_functor<T_functor, T_catcher>& _A_target)
+  static void do_visit_each(const T_action& action,
+    const exception_catch_functor<T_functor, T_catcher>& target)
   {
-    sigc::visit_each(_A_action, _A_target.functor_);
-    sigc::visit_each(_A_action, _A_target.catcher_);
+    sigc::visit_each(action, target.functor_);
+    sigc::visit_each(action, target.catcher_);
   }
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
-template <class T_functor, class T_catcher>
+template <typename T_functor, typename T_catcher>
 inline decltype(auto)
-exception_catch(const T_functor& _A_func, const T_catcher& _A_catcher)
+exception_catch(const T_functor& func, const T_catcher& catcher)
 {
-  return exception_catch_functor<T_functor, T_catcher>(_A_func, _A_catcher);
+  return exception_catch_functor<T_functor, T_catcher>(func, catcher);
 }
 
 } /* namespace sigc */
-#endif /* _SIGC_ADAPTORS_EXCEPTION_CATCH_H_ */
+#endif /* SIGC_ADAPTORS_EXCEPTION_CATCH_H */
