@@ -40,14 +40,14 @@ using hook = void* (*)(void*);
  *
  * The base class slot_rep serves the purpose to
  * - form a common pointer type (slot_rep*),
- * - offer the possibility to create duplicates (dup()),
- * - offer a notification callback (notify()),
+ * - offer the possibility to create duplicates (clone()),
+ * - offer a notification callback (notify_slot_rep_invalidated()),
  * - implement some of slot_base's interface that depends
  *   on the notification callback, i.e.
  *   -# the possibility to set a single parent with a callback
- *      (set_parent()) that is executed from notify(),
+ *      (set_parent()) that is executed from notify_slot_rep_invalidated(),
  *   -# a generic function pointer, call_, that is simply
- *      set to zero in notify() to invalidate the slot.
+ *      set to zero in notify_slot_rep_invalidated() to invalidate the slot.
  *
  * slot_rep inherits trackable so that connection objects can
  * refer to the slot and are notified when the slot is destroyed.
@@ -66,20 +66,14 @@ public:
    * down dereferencing of slot list iterators. Martin. */
   // TODO: Try this now? murrayc.
 
-  using hook_dup = slot_rep* (*)(slot_rep*);
-
-  using func_slot_rep_destroy_notify = void (*)(slot_rep* data);
-
-  inline slot_rep(hook call__, func_slot_rep_destroy_notify destroy__, hook_dup dup__) noexcept
+  inline slot_rep(hook call__) noexcept
     : call_(call__),
       cleanup_(nullptr),
-      parent_(nullptr),
-      destroy_(destroy__),
-      dup_(dup__)
+      parent_(nullptr)
   {
   }
 
-  inline ~slot_rep() { destroy(); }
+  virtual ~slot_rep() {}
 
 // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
 #ifdef SIGC_NEW_DELETE_IN_LIBRARY_ONLY
@@ -89,24 +83,17 @@ public:
 
   /** Destroys the slot_rep object (but doesn't delete it).
    */
-  inline void destroy()
-  {
-    if (destroy_)
-      (*destroy_)(this);
-  }
+  virtual void destroy() = 0;
 
   /** Makes a deep copy of the slot_rep object.
    * @return A deep copy of the slot_rep object.
    */
-  inline slot_rep* dup() const
-  {
-    return static_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this)));
-  }
+  virtual slot_rep* clone() const = 0;
 
   /** Set the parent with a callback.
    * slots have one parent exclusively.
    * @param parent The new parent.
-   * @param cleanup The callback to execute from notify().
+   * @param cleanup The callback to execute from notify_slot_rep_invalidated().
    */
   inline void set_parent(notifiable* parent, notifiable::func_destroy_notify cleanup) noexcept
   {
@@ -148,23 +135,10 @@ public:
 
   /** Parent object whose callback cleanup_ is executed on notification. */
   notifiable* parent_;
-
-protected:
-  /// Callback that detaches the slot_rep object from referred trackables and destroys it.
-  /* This could be a replaced by a virtual dtor. However, since this struct is
-   * crucial for the efficiency of the whole library, we want to avoid this.
-   */
-  func_slot_rep_destroy_notify destroy_;
-
-private:
-  /** Callback that makes a deep copy of the slot_rep object.
-   * @return A deep copy of the slot_rep object.
-   */
-  hook_dup dup_;
 };
 
 /** Functor used to add a dependency to a trackable.
- * Consequently slot_rep::notify() gets executed when the
+ * Consequently slot_rep::notify_slot_rep_invalidated() gets executed when the
  * trackable is destroyed or overwritten.
  */
 struct SIGC_API slot_do_bind
