@@ -38,7 +38,8 @@ trackable::trackable(const trackable& /*src*/) noexcept : callback_list_(nullptr
 //
 // If trackable's move constructor is modified, check if Glib::Object's
 // move constructor should be modified similarly.
-trackable::trackable(trackable&& src) : callback_list_(nullptr)
+trackable::trackable(trackable&& src) noexcept
+: callback_list_(nullptr)
 {
   src.notify_callbacks();
 }
@@ -53,7 +54,7 @@ trackable::operator=(const trackable& src)
 }
 
 trackable&
-trackable::operator=(trackable&& src)
+trackable::operator=(trackable&& src) noexcept
 {
   if (this != &src)
   {
@@ -83,9 +84,7 @@ trackable::remove_destroy_notify_callback(notifiable* data) const
 void
 trackable::notify_callbacks()
 {
-  if (callback_list_)
-    delete callback_list_; // This invokes all of the callbacks.
-
+  delete callback_list_; // This invokes all of the callbacks.
   callback_list_ = nullptr;
 }
 
@@ -120,7 +119,7 @@ trackable_callback_list::add_callback(notifiable* data, func_destroy_notify func
   // I'd consider this a serious application bug, since the app is likely to segfault.
   // But then, how should we handle it? Throw an exception? Martin.
   if (!clearing_)
-    callbacks_.push_back(trackable_callback(data, func));
+    callbacks_.emplace_back(trackable_callback(data, func));
 }
 
 void
