@@ -4,8 +4,6 @@
 
 #include "testutilities.h"
 #include <sigc++/adaptors/compose.h>
-#include <sstream>
-#include <cstdlib>
 
 namespace
 {
@@ -63,7 +61,7 @@ struct get
   double operator()()
   {
     result_stream << "get() ";
-    return true;
+    return static_cast<double>(true);
   }
 
   double operator()(int i)
